@@ -2,11 +2,14 @@ package chezmoi
 
 import (
 	"errors"
+	"fmt"
 	"io/fs"
 	"os"
+	"syscall"
 	"time"
 
 	"go.etcd.io/bbolt"
+	"golang.org/x/exp/slices"
 )
 
 // A BoltPersistentStateMode is a mode for opening a PersistentState.
@@ -28,7 +31,11 @@ type BoltPersistentState struct {
 }
 
 // NewBoltPersistentState returns a new BoltPersistentState.
-func NewBoltPersistentState(system System, path AbsPath, mode BoltPersistentStateMode) (*BoltPersistentState, error) {
+func NewBoltPersistentState(
+	system System,
+	path AbsPath,
+	mode BoltPersistentStateMode,
+) (*BoltPersistentState, error) {
 	empty := false
 	switch _, err := system.Stat(path); {
 	case errors.Is(err, fs.ErrNotExist):
@@ -86,7 +93,7 @@ func (b *BoltPersistentState) CopyTo(p PersistentState) error {
 	return b.db.View(func(tx *bbolt.Tx) error {
 		return tx.ForEach(func(bucket []byte, b *bbolt.Bucket) error {
 			return b.ForEach(func(key, value []byte) error {
-				return p.Set(copyByteSlice(bucket), copyByteSlice(key), copyByteSlice(value))
+				return p.Set(slices.Clone(bucket), slices.Clone(key), slices.Clone(value))
 			})
 		})
 	})
@@ -126,7 +133,7 @@ func (b *BoltPersistentState) DeleteBucket(bucket []byte) error {
 }
 
 // Data returns all the data in b.
-func (b *BoltPersistentState) Data() (interface{}, error) {
+func (b *BoltPersistentState) Data() (any, error) {
 	if b.empty {
 		return nil, nil
 	}
@@ -170,7 +177,7 @@ func (b *BoltPersistentState) ForEach(bucket []byte, fn func(k, v []byte) error)
 			return nil
 		}
 		return b.ForEach(func(k, v []byte) error {
-			return fn(copyByteSlice(k), copyByteSlice(v))
+			return fn(slices.Clone(k), slices.Clone(v))
 		})
 	})
 }
@@ -190,7 +197,7 @@ func (b *BoltPersistentState) Get(bucket, key []byte) ([]byte, error) {
 		if b == nil {
 			return nil
 		}
-		value = copyByteSlice(b.Get(key))
+		value = slices.Clone(b.Get(key))
 		return nil
 	}); err != nil {
 		return nil, err
@@ -219,24 +226,18 @@ func (b *BoltPersistentState) open() error {
 	if b.db != nil {
 		return nil
 	}
-	if err := MkdirAll(b.system, b.path.Dir(), 0o777); err != nil {
+	if err := MkdirAll(b.system, b.path.Dir(), fs.ModePerm); err != nil {
 		return err
 	}
-	db, err := bbolt.Open(b.path.String(), 0o600, &b.options)
-	if err != nil {
-		return err
-	}
-	b.empty = false
-	b.db = db
-	return nil
-}
-
-// copyByteSlice returns a copy of value.
-func copyByteSlice(value []byte) []byte {
-	if value == nil {
+	switch db, err := bbolt.Open(b.path.String(), 0o600, &b.options); {
+	case errors.Is(err, syscall.EINVAL):
+		// Assume that any EINVAL error is because flock(2) failed.
+		return fmt.Errorf("open %s: failed to acquire lock: %w", b.path, err)
+	case err != nil:
+		return fmt.Errorf("open %s: %w", b.path, err)
+	default:
+		b.empty = false
+		b.db = db
 		return nil
 	}
-	result := make([]byte, len(value))
-	copy(result, value)
-	return result
 }
