@@ -3,14 +3,15 @@ package chezmoi
 import (
 	"testing"
 
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 )
 
 func TestFormats(t *testing.T) {
-	assert.Contains(t, Formats, "json")
-	assert.Contains(t, Formats, "toml")
-	assert.Contains(t, Formats, "yaml")
+	assert.NotZero(t, FormatsByName["json"])
+	assert.NotZero(t, FormatsByName["jsonc"])
+	assert.NotZero(t, FormatsByName["toml"])
+	assert.NotZero(t, FormatsByName["yaml"])
+	assert.Zero(t, FormatsByName["yml"])
 }
 
 func TestFormatRoundTrip(t *testing.T) {
@@ -18,13 +19,12 @@ func TestFormatRoundTrip(t *testing.T) {
 		Bool   bool
 		Bytes  []byte
 		Int    int
-		Float  float64
-		Object map[string]interface{}
+		Object map[string]any
 		String string
 	}
 
 	for _, format := range []Format{
-		formatGzippedJSON{},
+		formatJSONC{},
 		formatJSON{},
 		formatTOML{},
 		formatYAML{},
@@ -34,16 +34,15 @@ func TestFormatRoundTrip(t *testing.T) {
 				Bool:  true,
 				Bytes: []byte("bytes"),
 				Int:   1,
-				Float: 2.3,
-				Object: map[string]interface{}{
+				Object: map[string]any{
 					"key": "value",
 				},
 				String: "string",
 			}
 			data, err := format.Marshal(v)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			var actualValue value
-			require.NoError(t, format.Unmarshal(data, &actualValue))
+			assert.NoError(t, format.Unmarshal(data, &actualValue))
 			assert.Equal(t, v, actualValue)
 		})
 	}
