@@ -10,6 +10,10 @@ import (
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
 )
 
+type chattrCmdConfig struct {
+	recursive bool
+}
+
 type boolModifier int
 
 const (
@@ -38,6 +42,14 @@ const (
 	orderModifierSetAfter       orderModifier = 2
 )
 
+type sourceDirTypeModifier int
+
+const (
+	sourceDirTypeModifierLeaveUnchanged sourceDirTypeModifier = iota
+	sourceDirTypeModifierSetRemove
+	sourceDirTypeModifierClearRemove
+)
+
 type sourceFileTypeModifier int
 
 const (
@@ -46,6 +58,8 @@ const (
 	sourceFileTypeModifierClearCreate
 	sourceFileTypeModifierSetModify
 	sourceFileTypeModifierClearModify
+	sourceFileTypeModifierSetRemove
+	sourceFileTypeModifierClearRemove
 	sourceFileTypeModifierSetScript
 	sourceFileTypeModifierClearScript
 	sourceFileTypeModifierSetSymlink
@@ -53,12 +67,14 @@ const (
 )
 
 type modifier struct {
+	sourceDirType  sourceDirTypeModifier
 	sourceFileType sourceFileTypeModifier
 	condition      conditionModifier
 	empty          boolModifier
 	encrypted      boolModifier
 	exact          boolModifier
 	executable     boolModifier
+	external       boolModifier
 	order          orderModifier
 	private        boolModifier
 	readOnly       boolModifier
@@ -74,11 +90,21 @@ func (c *Config) newChattrCmd() *cobra.Command {
 		Args:              cobra.MinimumNArgs(2),
 		ValidArgsFunction: c.chattrCmdValidArgs,
 		RunE:              c.makeRunEWithSourceState(c.runChattrCmd),
-		Annotations: map[string]string{
-			modifiesSourceDirectory: "true",
-		},
+		Annotations: newAnnotations(
+			modifiesSourceDirectory,
+			requiresSourceDirectory,
+		),
 	}
 
+	flags := chattrCmd.Flags()
+	flags.BoolVarP(
+		&c.chattr.recursive,
+		"recursive",
+		"r",
+		c.chattr.recursive,
+		"Recurse into subdirectories",
+	)
+
 	return chattrCmd
 }
 
@@ -97,11 +123,13 @@ func (c *Config) chattrCmdValidArgs(
 			"encrypted",
 			"exact",
 			"executable",
+			"external",
 			"modify",
 			"once",
 			"onchange",
 			"private",
 			"readonly",
+			"remove",
 			"script",
 			"symlink",
 			"template",
@@ -131,7 +159,11 @@ func (c *Config) chattrCmdValidArgs(
 	}
 }
 
-func (c *Config) runChattrCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
+func (c *Config) runChattrCmd(
+	cmd *cobra.Command,
+	args []string,
+	sourceState *chezmoi.SourceState,
+) error {
 	// LATER should the core functionality of chattr move to chezmoi.SourceState?
 
 	m, err := parseModifier(args[0])
@@ -140,7 +172,8 @@ func (c *Config) runChattrCmd(cmd *cobra.Command, args []string, sourceState *ch
 	}
 
 	targetRelPaths, err := c.targetRelPaths(sourceState, args[1:], targetRelPathsOptions{
-		mustBeInSourceState: true,
+		mustBeManaged: true,
+		recursive:     c.chattr.recursive,
 	})
 	if err != nil {
 		return err
@@ -148,7 +181,7 @@ func (c *Config) runChattrCmd(cmd *cobra.Command, args []string, sourceState *ch
 
 	// Sort targets in reverse so we update children before their parent
 	// directories.
-	sort.Sort(targetRelPaths)
+	sort.Sort(sort.Reverse(targetRelPaths))
 
 	encryptedSuffix := sourceState.Encryption().EncryptedSuffix()
 	for _, targetRelPath := range targetRelPaths {
@@ -168,12 +201,41 @@ func (c *Config) runChattrCmd(cmd *cobra.Command, args []string, sourceState *ch
 				}
 			}
 		case *chezmoi.SourceStateFile:
-			// FIXME encrypted attribute changes
-			// FIXME when changing encrypted attribute add new file before removing old one
-			relPath := m.modifyFileAttr(sourceStateEntry.Attr).SourceName(encryptedSuffix)
-			if newBaseNameRelPath := chezmoi.NewRelPath(relPath); newBaseNameRelPath != fileRelPath {
-				oldSourceAbsPath := c.SourceDirAbsPath.Join(parentRelPath, fileRelPath)
-				newSourceAbsPath := c.SourceDirAbsPath.Join(parentRelPath, newBaseNameRelPath)
+			newAttr := m.modifyFileAttr(sourceStateEntry.Attr)
+			newBaseNameRelPath := chezmoi.NewRelPath(newAttr.SourceName(encryptedSuffix))
+			oldSourceAbsPath := c.SourceDirAbsPath.Join(parentRelPath, fileRelPath)
+			newSourceAbsPath := c.SourceDirAbsPath.Join(parentRelPath, newBaseNameRelPath)
+			switch encryptedBefore, encryptedAfter := sourceStateEntry.Attr.Encrypted, newAttr.Encrypted; {
+			case encryptedBefore && !encryptedAfter:
+				// Write the plaintext and then remove the ciphertext.
+				plaintext, err := sourceStateEntry.Contents()
+				if err != nil {
+					return err
+				}
+				if err := c.sourceSystem.WriteFile(newSourceAbsPath, plaintext, 0o666&^c.Umask); err != nil {
+					return err
+				}
+				if err := c.sourceSystem.Remove(oldSourceAbsPath); err != nil {
+					return err
+				}
+			case !encryptedBefore && encryptedAfter:
+				// Write the ciphertext and then remove the plaintext.
+				plaintext, err := sourceStateEntry.Contents()
+				if err != nil {
+					return err
+				}
+				ciphertext, err := sourceState.Encryption().Encrypt(plaintext)
+				if err != nil {
+					return err
+				}
+				if err := c.sourceSystem.WriteFile(newSourceAbsPath, ciphertext, 0o666&^c.Umask); err != nil {
+					return err
+				}
+				if err := c.sourceSystem.Remove(oldSourceAbsPath); err != nil {
+					return err
+				}
+			case newBaseNameRelPath != fileRelPath:
+				// Contents have not changed so a rename is sufficient.
 				if err := c.sourceSystem.Rename(oldSourceAbsPath, newSourceAbsPath); err != nil {
 					return err
 				}
@@ -247,7 +309,28 @@ func (m orderModifier) modify(order chezmoi.ScriptOrder) chezmoi.ScriptOrder {
 }
 
 // modify returns the modified value of type.
-func (m sourceFileTypeModifier) modify(sourceFileType chezmoi.SourceFileTargetType) chezmoi.SourceFileTargetType {
+func (m sourceDirTypeModifier) modify(
+	sourceDirType chezmoi.SourceDirTargetType,
+) chezmoi.SourceDirTargetType {
+	switch m {
+	case sourceDirTypeModifierLeaveUnchanged:
+		return sourceDirType
+	case sourceDirTypeModifierSetRemove:
+		return chezmoi.SourceDirTypeRemove
+	case sourceDirTypeModifierClearRemove:
+		if sourceDirType == chezmoi.SourceDirTypeRemove {
+			return chezmoi.SourceDirTypeDir
+		}
+		return sourceDirType
+	default:
+		panic(fmt.Sprintf("%d: unknown type modifier", m))
+	}
+}
+
+// modify returns the modified value of type.
+func (m sourceFileTypeModifier) modify(
+	sourceFileType chezmoi.SourceFileTargetType,
+) chezmoi.SourceFileTargetType {
 	switch m {
 	case sourceFileTypeModifierLeaveUnchanged:
 		return sourceFileType
@@ -258,6 +341,13 @@ func (m sourceFileTypeModifier) modify(sourceFileType chezmoi.SourceFileTargetTy
 			return chezmoi.SourceFileTypeFile
 		}
 		return sourceFileType
+	case sourceFileTypeModifierSetRemove:
+		return chezmoi.SourceFileTypeRemove
+	case sourceFileTypeModifierClearRemove:
+		if sourceFileType == chezmoi.SourceFileTypeRemove {
+			return chezmoi.SourceFileTypeFile
+		}
+		return sourceFileType
 	case sourceFileTypeModifierSetModify:
 		return chezmoi.SourceFileTypeModify
 	case sourceFileTypeModifierClearModify:
@@ -284,7 +374,7 @@ func (m sourceFileTypeModifier) modify(sourceFileType chezmoi.SourceFileTargetTy
 	}
 }
 
-// parseModifier parses the attrMmodifier from s.
+// parseModifier parses the modifier from s.
 func parseModifier(s string) (*modifier, error) {
 	m := &modifier{}
 	for _, modifierStr := range strings.Split(s, ",") {
@@ -342,6 +432,8 @@ func parseModifier(s string) (*modifier, error) {
 			m.exact = bm
 		case "executable", "x":
 			m.executable = bm
+		case "external":
+			m.external = bm
 		case "modify":
 			switch bm {
 			case boolModifierClear:
@@ -367,6 +459,15 @@ func parseModifier(s string) (*modifier, error) {
 			m.private = bm
 		case "readonly", "r":
 			m.readOnly = bm
+		case "remove":
+			switch bm {
+			case boolModifierClear:
+				m.sourceDirType = sourceDirTypeModifierClearRemove
+				m.sourceFileType = sourceFileTypeModifierClearRemove
+			case boolModifierSet:
+				m.sourceDirType = sourceDirTypeModifierSetRemove
+				m.sourceFileType = sourceFileTypeModifierSetRemove
+			}
 		case "script":
 			switch bm {
 			case boolModifierClear:
@@ -392,11 +493,23 @@ func parseModifier(s string) (*modifier, error) {
 
 // modifyDirAttr returns the modified value of dirAttr.
 func (m *modifier) modifyDirAttr(dirAttr chezmoi.DirAttr) chezmoi.DirAttr {
-	return chezmoi.DirAttr{
-		TargetName: dirAttr.TargetName,
-		Exact:      m.exact.modify(dirAttr.Exact),
-		Private:    m.private.modify(dirAttr.Private),
-		ReadOnly:   m.readOnly.modify(dirAttr.ReadOnly),
+	switch m.sourceDirType.modify(dirAttr.Type) {
+	case chezmoi.SourceDirTypeDir:
+		return chezmoi.DirAttr{
+			TargetName: dirAttr.TargetName,
+			Type:       chezmoi.SourceDirTypeDir,
+			Exact:      m.exact.modify(dirAttr.Exact),
+			External:   m.external.modify(dirAttr.External),
+			Private:    m.private.modify(dirAttr.Private),
+			ReadOnly:   m.readOnly.modify(dirAttr.ReadOnly),
+		}
+	case chezmoi.SourceDirTypeRemove:
+		return chezmoi.DirAttr{
+			TargetName: dirAttr.TargetName,
+			Type:       chezmoi.SourceDirTypeRemove,
+		}
+	default:
+		panic(fmt.Sprintf("%d: unknown source dir type", dirAttr.Type))
 	}
 }
 
@@ -427,6 +540,7 @@ func (m *modifier) modifyFileAttr(fileAttr chezmoi.FileAttr) chezmoi.FileAttr {
 		return chezmoi.FileAttr{
 			TargetName: fileAttr.TargetName,
 			Type:       chezmoi.SourceFileTypeCreate,
+			Empty:      m.encrypted.modify(fileAttr.Empty),
 			Encrypted:  m.encrypted.modify(fileAttr.Encrypted),
 			Executable: m.executable.modify(fileAttr.Executable),
 			Private:    m.private.modify(fileAttr.Private),
