@@ -6,10 +6,6 @@ import (
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
 )
 
-type dataCmdConfig struct {
-	format writeDataFormat
-}
-
 func (c *Config) newDataCmd() *cobra.Command {
 	dataCmd := &cobra.Command{
 		Use:     "data",
@@ -21,17 +17,20 @@ func (c *Config) newDataCmd() *cobra.Command {
 	}
 
 	persistentFlags := dataCmd.PersistentFlags()
-	persistentFlags.VarP(&c.data.format, "format", "f", "format")
+	persistentFlags.VarP(&c.Format, "format", "f", "Output format")
+	if err := dataCmd.RegisterFlagCompletionFunc("format", writeDataFormatFlagCompletionFunc); err != nil {
+		panic(err)
+	}
 
 	return dataCmd
 }
 
 func (c *Config) runDataCmd(cmd *cobra.Command, args []string) error {
-	sourceState, err := c.newSourceState(cmd.Context(),
+	sourceState, err := c.newSourceState(cmd.Context(), cmd,
 		chezmoi.WithTemplateDataOnly(true),
 	)
 	if err != nil {
 		return err
 	}
-	return c.marshal(c.data.format, sourceState.TemplateData())
+	return c.marshal(c.Format, sourceState.TemplateData())
 }
