@@ -11,7 +11,8 @@ import (
 )
 
 type statusCmdConfig struct {
-	Exclude   *chezmoi.EntryTypeSet `json:"exclude" mapstructure:"exclude" yaml:"exclude"`
+	Exclude   *chezmoi.EntryTypeSet `json:"exclude"   mapstructure:"exclude"   yaml:"exclude"`
+	PathStyle *chezmoi.PathStyle    `json:"pathStyle" mapstructure:"pathStyle" yaml:"pathStyle"`
 	include   *chezmoi.EntryTypeSet
 	init      bool
 	recursive bool
@@ -26,6 +27,7 @@ func (c *Config) newStatusCmd() *cobra.Command {
 		ValidArgsFunction: c.targetValidArgs,
 		RunE:              c.runStatusCmd,
 		Annotations: newAnnotations(
+			dryRun,
 			modifiesDestinationDirectory,
 			persistentStateModeReadMockWrite,
 			requiresSourceDirectory,
@@ -34,6 +36,7 @@ func (c *Config) newStatusCmd() *cobra.Command {
 
 	flags := statusCmd.Flags()
 	flags.VarP(c.Status.Exclude, "exclude", "x", "Exclude entry types")
+	flags.VarP(c.Status.PathStyle, "path-style", "p", "Path style")
 	flags.VarP(c.Status.include, "include", "i", "Include entry types")
 	flags.BoolVar(&c.Status.init, "init", c.Status.init, "Recreate config file from template")
 	flags.BoolVarP(
@@ -51,7 +54,6 @@ func (c *Config) newStatusCmd() *cobra.Command {
 
 func (c *Config) runStatusCmd(cmd *cobra.Command, args []string) error {
 	builder := strings.Builder{}
-	dryRunSystem := chezmoi.NewDryRunSystem(c.destSystem)
 	preApplyFunc := func(
 		targetRelPath chezmoi.RelPath, targetEntryState, lastWrittenEntryState, actualEntryState *chezmoi.EntryState,
 	) error {
@@ -73,12 +75,25 @@ func (c *Config) runStatusCmd(cmd *cobra.Command, args []string) error {
 			x = statusRune(lastWrittenEntryState, actualEntryState)
 			y = statusRune(actualEntryState, targetEntryState)
 		}
+
 		if x != ' ' || y != ' ' {
-			fmt.Fprintf(&builder, "%c%c %s\n", x, y, targetRelPath)
+			var path string
+			switch *c.Status.PathStyle {
+			case chezmoi.PathStyleAbsolute:
+				path = c.DestDirAbsPath.Join(targetRelPath).String()
+			case chezmoi.PathStyleRelative:
+				path = targetRelPath.String()
+			case chezmoi.PathStyleSourceAbsolute:
+				return fmt.Errorf("source-absolute not supported for status")
+			case chezmoi.PathStyleSourceRelative:
+				return fmt.Errorf("source-relative not supported for status")
+			}
+
+			fmt.Fprintf(&builder, "%c%c %s\n", x, y, path)
 		}
 		return fs.SkipDir
 	}
-	if err := c.applyArgs(cmd.Context(), dryRunSystem, c.DestDirAbsPath, args, applyArgsOptions{
+	if err := c.applyArgs(cmd.Context(), c.destSystem, c.DestDirAbsPath, args, applyArgsOptions{
 		cmd:          cmd,
 		filter:       chezmoi.NewEntryTypeFilter(c.Status.include.Bits(), c.Status.Exclude.Bits()),
 		init:         c.Status.init,
