@@ -116,7 +116,9 @@ func run() error {
 	})
 
 	// Generate install.sh.
-	installShTemplate, err := template.ParseFiles("internal/cmds/generate-install.sh/install.sh.tmpl")
+	installShTemplate, err := template.ParseFiles(
+		"internal/cmds/generate-install.sh/install.sh.tmpl",
+	)
 	if err != nil {
 		return err
 	}
